summaryrefslogtreecommitdiff
path: root/hints/aix.sh
diff options
context:
space:
mode:
Diffstat (limited to 'hints/aix.sh')
-rw-r--r--hints/aix.sh15
1 files changed, 9 insertions, 6 deletions
diff --git a/hints/aix.sh b/hints/aix.sh
index a7c8df2b64..8d06c9fc72 100644
--- a/hints/aix.sh
+++ b/hints/aix.sh
@@ -539,10 +539,13 @@ libswanted=`echo " $libswanted " | sed -e 's/ BSD / /'`
d_flock='undef'
# remove libgdbm from wanted libraries
-# The libgdbm 1.8.3 from the AIX Toolbox is not working
-# (the dbm_store() function is defective)
-libswanted=`echo " $libswanted " | sed -e 's/ gdbm / /'`
-i_gdbm='undef'
-i_gdbmndbm='undef'
-
+# The libgdbm < 1.8.3-5 from the AIX Toolbox is not working
+# because two wrong .h are present
+if [ -f "/opt/freeware/include/gdbm/dbm.h" ] ||
+ [ -f "/opt/freeware/include/gdbm/ndbm.h" ]; then
+ echo "GDBM support disabled because your GDBM package contains extraneous headers - see README.aix."
+ libswanted=`echo " $libswanted " | sed -e 's/ gdbm / /'`
+ i_gdbm='undef'
+ i_gdbmndbm='undef'
+fi
# EOF